# rough-theory
The `rough-theory` library offers various operations to analyze and leverage discernibility of knowledge. It uses minimal dependencies to implement these features and has a graph theory backend (via `igraph`).
